from enum import Enum


class Formats(Enum):
    PDF = "pdf"
    TXT = "txt"
    DOCX = "docx"
    HTML = "html"
    RICH_TEXT = "rtf"
    OPEN_DOCUMENT_TEXT = "odt"
    EPUB = "epub"
    ZIP = "zip"



import logging

logger = logging.getLogger("gdoc-dumper")

handler = logging.StreamHandler()
formatter = logging.Formatter("%(asctime)s - %(name)s - %(levelname)s - %(message)s")
handler.setFormatter(formatter)

logger.addHandler(handler)
logger.setLevel(logging.DEBUG)



from gdoc_dumper import Formats

print(Formats.TXT.value)
print(Formats.PDF.value)
print(Formats.DOCX.value)
print(Formats.EPUB.value)
print(Formats.HTML.value)
print(Formats.OPEN_DOCUMENT_TEXT.value)
print(Formats.RICH_TEXT.value)
print(Formats.ZIP.value)
